@@ -142,7 +142,7 @@ class Ref:  # pylint: disable=too-many-instance-attributes
                     await con.execute(
                         f"""CREATE TABLE event_{self.session_id} PARTITION OF event
                             FOR VALUES IN ({self.session_id});
-                        """              )
+                        """)
                 LOG.info("Session session data saved...")
         except IndexError:
             pass
@@ -528,16 +528,39 @@ class BinCopyWriter:
     fmt_str: str = '>h ii ii if i? if if if if if if if if if if ii'
     copy_header = struct.pack('>11sii', b'PGCOPY\n\377\r\n\0', 0, 0)
     copy_trailer =  struct.pack('>h', -1)
-    tbl_uuid = str(uuid1()).replace("-", '_')
-    cmd = f"""
-            CREATE UNLOGGED TABLE IF NOT EXISTS "{tbl_uuid}"
-                (LIKE event INCLUDING DEFAULTS);
 
-            COPY public."{tbl_uuid}" FROM STDIN WITH BINARY;
 
-            CREATE INDEX tmp_idx on "{tbl_uuid}" (id, updates DESC);
+    # """
+    # WITH src AS (
+    #     UPDATE serial_rate
+    #     SET rate = 22.53, serial_key = '0002'
+    #     WHERE serial_key = '002' AND id = '01'
+    #     RETURNING *
+    #     )
+    # UPDATE serial_table dst
+    # SET serial_key = src.serial_key
+    # FROM src
+    # -- WHERE dst.id = src.id AND dst.serial_key  = '002'
+    # WHERE dst.id = '01' AND dst.serial_key  = '002';
+    # """
 
-            INSERT INTO event
+    def __init__(self, dsn: str, batch_size: int = 10000, session_id=None):
+        self.dsn = dsn
+        self.batch_size = batch_size
+        self.build_fmt_string()
+        self.create_byte_buffer()
+        self.insert_count = 0
+        self.session_id = session_id
+        self.tbl_uuid = str(uuid1()).replace("-", '_')
+        self.cmd = f"""
+            CREATE UNLOGGED TABLE IF NOT EXISTS "{self.tbl_uuid}"
+                (LIKE event_{self.session_id} INCLUDING DEFAULTS);
+
+            COPY public."{self.tbl_uuid}" FROM STDIN WITH BINARY;
+
+            CREATE INDEX tmp_idx on "{self.tbl_uuid}" (id, updates DESC);
+
+            INSERT INTO event_{self.session_id}
             SELECT * FROM "{tbl_uuid}";
 
             INSERT INTO object (
@@ -551,7 +574,7 @@ class BinCopyWriter:
                     row_number() OVER (
                         PARTITION BY id
                         ORDER BY updates DESC) as row_number
-                FROM "{tbl_uuid}"
+                FROM "{self.tbl_uuid}"
             ) evt
             WHERE row_number = 1
             ON CONFLICT (id)
@@ -572,30 +595,9 @@ class BinCopyWriter:
             WHERE object.updates < EXCLUDED.updates;
 
             DROP INDEX tmp_idx;
-            DROP TABLE "{tbl_uuid}";
+            DROP TABLE "{self.tbl_uuid}";
         """
 
-    # """
-    # WITH src AS (
-    #     UPDATE serial_rate
-    #     SET rate = 22.53, serial_key = '0002'
-    #     WHERE serial_key = '002' AND id = '01'
-    #     RETURNING *
-    #     )
-    # UPDATE serial_table dst
-    # SET serial_key = src.serial_key
-    # FROM src
-    # -- WHERE dst.id = src.id AND dst.serial_key  = '002'
-    # WHERE dst.id = '01' AND dst.serial_key  = '002';
-    # """
-
-    def __init__(self, dsn: str, batch_size: int = 10000):
-        self.dsn = dsn
-        self.batch_size = batch_size
-        self.build_fmt_string()
-        self.create_byte_buffer()
-        self.insert_count = 0
-
     def build_fmt_string(self):
         {
             "INTEGER": ('ii', 4),
